==> jc-1.4.0.tar.gz: org/dellroad/jc/cgen/JCObjectGenerator__24CopyOut.h <==
// class org.dellroad.jc.cgen.JCObjectGenerator$CopyOut

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a3a7cdc3e4c7ce28 java_lang_Thread
// @dep_class 51e031d992aaa37e org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut

// header file dependencies
// @dep_header java_lang_Thread

#include "java/lang/Thread.h"

#ifndef _JC_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut_H_
#define _JC_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$sub_refs	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$sub_nonrefs	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$refs	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$refs;
typedef struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$nonrefs	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$object	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$object;

typedef const struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$vmethods	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$vtable	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$vtype	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$method$_init$3887600c17c5e554(_jc_env *, struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$object *, struct _jc_java_io_InputStream$object *);

// Virtual methods
extern void _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$object *);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$method_info$run$8b940e4957c86ebf;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$vmethods {
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$object *);
};

// Vtable
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Thread$vmethods	java_lang_Thread;
	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$vmethods	org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$sub_refs {
	struct _jc_java_io_InputStream$object	*input;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$refs {
    _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$sub_refs	org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut;
    _jc_java_lang_Thread$sub_refs	java_lang_Thread;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Thread$sub_nonrefs	java_lang_Thread;
    _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$sub_nonrefs	org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$object {
	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$vtype _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/cgen/JCObjectGenerator__24CopyOut.h <==
// class org.dellroad.jc.cgen.JCObjectGenerator$CopyOut

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7e33d4feabbc3f15 java_lang_Thread
// @dep_class 51e031d992aaa37e org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut

// header file dependencies
// @dep_header java_lang_Thread

#include "java/lang/Thread.h"

#ifndef _JC_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut_H_
#define _JC_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$sub_refs	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$sub_refs;
typedef struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$sub_nonrefs	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$refs	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$refs;
typedef struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$nonrefs	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$nonrefs;
typedef struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$object	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$object;

typedef const struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$vmethods	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$vmethods;
typedef const struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$vtable	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$vtable;
typedef const struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$vtype	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$vtype;

// Constructors
extern void _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$method$_init$3887600c17c5e554(_jc_env *, struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$object *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$method$run$8b940e4957c86ebf(_jc_env *, struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$method_info$run$8b940e4957c86ebf;

// Virtual methods structure
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$vmethods {
	void	(*run$8b940e4957c86ebf)(_jc_env *, struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Thread$vmethods	java_lang_Thread;
	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$vmethods	org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut;
};

// Vtype
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$sub_refs {
	struct _jc_java_io_InputStream$object	*input;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$refs {
    _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$sub_refs	org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut;
    _jc_java_lang_Thread$sub_refs	java_lang_Thread;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Thread$sub_nonrefs	java_lang_Thread;
    _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$sub_nonrefs	org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut;
};

// Object instance structure
struct _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$object {
	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$vtype	*vtype;
	_jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$vtype _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut$class_object;

#endif	/* _JC_org_dellroad_jc_cgen_JCObjectGenerator__24CopyOut_H_ */
